@@ -2,6 +2,8 @@ import sys
 import typing
 import bpy_types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class VIEW3D_OT_edit_mesh_extrude_individual_move(bpy_types.Operator):
     bl_idname = None
@@ -16,9 +18,6 @@ class VIEW3D_OT_edit_mesh_extrude_individual_move(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -31,6 +30,18 @@ class VIEW3D_OT_edit_mesh_extrude_individual_move(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -55,7 +66,7 @@ class VIEW3D_OT_edit_mesh_extrude_individual_move(bpy_types.Operator):
         '''
         pass
 
-    def invoke(self, context, event):
+    def invoke(self, context, _event):
         ''' 
 
         '''
@@ -67,6 +78,12 @@ class VIEW3D_OT_edit_mesh_extrude_individual_move(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -121,6 +138,18 @@ class VIEW3D_OT_edit_mesh_extrude_individual_move(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -153,9 +182,6 @@ class VIEW3D_OT_edit_mesh_extrude_move(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -168,6 +194,18 @@ class VIEW3D_OT_edit_mesh_extrude_move(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -198,7 +236,7 @@ class VIEW3D_OT_edit_mesh_extrude_move(bpy_types.Operator):
         '''
         pass
 
-    def invoke(self, context, event):
+    def invoke(self, context, _event):
         ''' 
 
         '''
@@ -210,6 +248,12 @@ class VIEW3D_OT_edit_mesh_extrude_move(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -264,6 +308,18 @@ class VIEW3D_OT_edit_mesh_extrude_move(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -296,7 +352,171 @@ class VIEW3D_OT_edit_mesh_extrude_shrink_fatten(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
+    def as_keywords(self, ignore):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def execute(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def invoke(self, context, _event):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class VIEW3D_OT_transform_gizmo_set(bpy_types.Operator):
+    bl_idname = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
     ''' '''
 
     def as_keywords(self, ignore):
@@ -311,6 +531,18 @@ class VIEW3D_OT_edit_mesh_extrude_shrink_fatten(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -347,153 +579,7 @@ class VIEW3D_OT_edit_mesh_extrude_shrink_fatten(bpy_types.Operator):
         '''
         pass
 
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class VIEW3D_OT_select_or_deselect_all(bpy_types.Operator):
-    bl_idname = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_options = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    center = None
-    ''' '''
-
-    deselect = None
-    ''' '''
-
-    enumerate = None
-    ''' '''
-
-    extend = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    object = None
-    ''' '''
-
-    order = None
-    ''' '''
-
-    toggle = None
-    ''' '''
-
-    def as_keywords(self, ignore):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def invoke(self, context, event):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
+    def is_property_overridable_library(self):
         ''' 
 
         '''
@@ -553,6 +639,18 @@ class VIEW3D_OT_select_or_deselect_all(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
