@@ -4,6 +4,8 @@ import bpy_types
 import rna_prop_ui
 import bl_ui.properties_animviz
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class ArmatureButtonsPanel:
     bl_context = None
@@ -22,7 +24,7 @@ class ArmatureButtonsPanel:
         pass
 
 
-class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
+class DATA_MT_bone_group_context_menu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -44,7 +46,19 @@ class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -56,7 +70,7 @@ class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -92,6 +106,12 @@ class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -135,7 +155,7 @@ class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -147,12 +167,24 @@ class DATA_PT_bone_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -213,13 +245,25 @@ class DATA_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
         '''
         pass
 
-    def draw_settings(self, context, avs, mpath, bones):
+    def draw_settings(self, _context, avs, mpath, bones):
         ''' 
 
         '''
@@ -255,6 +299,12 @@ class DATA_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -309,12 +359,24 @@ class DATA_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -340,7 +402,9 @@ class DATA_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         pass
 
 
-class DATA_PT_onion_skinning(bl_ui.properties_animviz.OnionSkinButtonsPanel):
+class DATA_PT_motion_paths_display(
+        bl_ui.properties_animviz.MotionPathButtonsPanel_display,
+        bpy_types.Panel, bpy_types._GenericUI):
     bl_context = None
     ''' '''
 
@@ -350,31 +414,7 @@ class DATA_PT_onion_skinning(bl_ui.properties_animviz.OnionSkinButtonsPanel):
     bl_options = None
     ''' '''
 
-    bl_region_type = None
-    ''' '''
-
-    bl_space_type = None
-    ''' '''
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-
-class DATA_PT_bone_groups(ArmatureButtonsPanel, bpy_types.Panel,
-                          bpy_types._GenericUI):
-    bl_context = None
-    ''' '''
-
-    bl_label = None
+    bl_parent_id = None
     ''' '''
 
     bl_region_type = None
@@ -401,12 +441,30 @@ class DATA_PT_bone_groups(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
         '''
         pass
 
+    def draw_settings(self, _context, avs, mpath, bones):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -437,6 +495,12 @@ class DATA_PT_bone_groups(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -491,12 +555,210 @@ class DATA_PT_bone_groups(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class DATA_PT_bone_groups(ArmatureButtonsPanel, bpy_types.Panel,
+                          bpy_types._GenericUI):
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -557,6 +819,18 @@ class DATA_PT_context_arm(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -593,6 +867,12 @@ class DATA_PT_context_arm(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -647,12 +927,24 @@ class DATA_PT_context_arm(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -692,6 +984,9 @@ class DATA_PT_custom_props_arm(ArmatureButtonsPanel, rna_prop_ui.PropertyPanel,
     bl_options = None
     ''' '''
 
+    bl_order = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -716,6 +1011,18 @@ class DATA_PT_custom_props_arm(ArmatureButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -752,6 +1059,12 @@ class DATA_PT_custom_props_arm(ArmatureButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -806,12 +1119,24 @@ class DATA_PT_custom_props_arm(ArmatureButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -845,6 +1170,9 @@ class DATA_PT_display(ArmatureButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -869,6 +1197,18 @@ class DATA_PT_display(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -905,6 +1245,12 @@ class DATA_PT_display(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -959,154 +1305,7 @@ class DATA_PT_display(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class DATA_PT_ghost(ArmatureButtonsPanel, bpy_types.Panel,
-                    bpy_types._GenericUI):
-    bl_context = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    bl_space_type = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
+    def pop(self):
         ''' 
 
         '''
@@ -1118,6 +1317,12 @@ class DATA_PT_ghost(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1178,6 +1383,18 @@ class DATA_PT_iksolver_itasc(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1214,6 +1431,12 @@ class DATA_PT_iksolver_itasc(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1268,12 +1491,24 @@ class DATA_PT_iksolver_itasc(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1334,6 +1569,18 @@ class DATA_PT_pose_library(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1370,6 +1617,12 @@ class DATA_PT_pose_library(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1424,12 +1677,24 @@ class DATA_PT_pose_library(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1487,6 +1752,18 @@ class DATA_PT_skeleton(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1523,6 +1800,12 @@ class DATA_PT_skeleton(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1577,12 +1860,24 @@ class DATA_PT_skeleton(ArmatureButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
