@@ -4,12 +4,14 @@ import bpy.types
 
 from . import types
 from . import ops
-from . import app
 from . import utils
+from . import app
 from . import props
-from . import context
 from . import path
 
+GenericType = typing.TypeVar("GenericType")
+context: 'bpy.types.Context' = None
+
 data: 'bpy.types.BlendData' = None
 ''' Access to Blender's internal data
 '''
