@@ -1,16 +1,30 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def context_menu():
+def context_menu(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None):
     ''' Display properties editor context_menu
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def directory_browse(directory: str = "",
+def directory_browse(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: bool = None,
+                     *,
+                     directory: str = "",
                      hide_props_region: bool = True,
                      filter_blender: bool = False,
                      filter_backup: bool = False,
@@ -33,6 +47,9 @@ def directory_browse(directory: str = "",
                      sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Open a directory browser, Hold Shift to open the file, Alt to browse containing directory
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param directory: Directory, Directory of the file
     :type directory: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -80,7 +97,12 @@ def directory_browse(directory: str = "",
     pass
 
 
-def file_browse(filepath: str = "",
+def file_browse(override_context: typing.
+                Union[typing.Dict, 'bpy.types.Context'] = None,
+                execution_context: typing.Union[str, int] = None,
+                undo: bool = None,
+                *,
+                filepath: str = "",
                 hide_props_region: bool = True,
                 filter_blender: bool = False,
                 filter_backup: bool = False,
@@ -103,6 +125,9 @@ def file_browse(filepath: str = "",
                 sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Open a file browser, Hold Shift to open the file, Alt to browse containing directory
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
