@@ -1,8 +1,16 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def open(filepath: str = "",
+def open(override_context: typing.Union[typing.
+                                        Dict, 'bpy.types.Context'] = None,
+         execution_context: typing.Union[str, int] = None,
+         undo: bool = None,
+         *,
+         filepath: str = "",
          hide_props_region: bool = True,
          check_existing: bool = True,
          filter_blender: bool = False,
@@ -25,6 +33,9 @@ def open(filepath: str = "",
          sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Load a cache file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -72,9 +83,15 @@ def open(filepath: str = "",
     pass
 
 
-def reload():
+def reload(override_context: typing.Union[typing.
+                                          Dict, 'bpy.types.Context'] = None,
+           execution_context: typing.Union[str, int] = None,
+           undo: bool = None):
     ''' Update objects paths list with new data from the archive
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
