@@ -1,8 +1,16 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def ply(filepath: str = "",
+def ply(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.ply",
         use_selection: bool = False,
@@ -15,6 +23,9 @@ def ply(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Z'):
     ''' Export as a Stanford PLY with normals, vertex colors and texture coordinates
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -42,7 +53,12 @@ def ply(filepath: str = "",
     pass
 
 
-def stl(filepath: str = "",
+def stl(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.stl",
         use_selection: bool = False,
@@ -55,6 +71,9 @@ def stl(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Z'):
     ''' Save STL triangle mesh data
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
