@@ -1,8 +1,16 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def fbx(filepath: str = "",
+def fbx(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.fbx",
         use_selection: bool = False,
@@ -42,6 +50,9 @@ def fbx(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Write a FBX file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -119,7 +130,12 @@ def fbx(filepath: str = "",
     pass
 
 
-def gltf(export_format: typing.Union[str, int] = 'GLB',
+def gltf(override_context: typing.Union[typing.
+                                        Dict, 'bpy.types.Context'] = None,
+         execution_context: typing.Union[str, int] = None,
+         undo: bool = None,
+         *,
+         export_format: typing.Union[str, int] = 'GLB',
          ui_tab: typing.Union[str, int] = 'GENERAL',
          export_copyright: str = "",
          export_image_format: typing.Union[str, int] = 'NAME',
@@ -160,6 +176,9 @@ def gltf(export_format: typing.Union[str, int] = 'GLB',
          filter_glob: str = "*.glb;*.gltf"):
     ''' Export scene as glTF 2.0 file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param export_format: Format, Output format and embedding options. Binary is most efficient, but JSON (embedded or separate) may be easier to edit later * GLB glTF Binary (.glb), Exports a single file, with all data packed in binary form. Most efficient and portable, but more difficult to edit later. * GLTF_EMBEDDED glTF Embedded (.gltf), Exports a single file, with all data packed in JSON. Less efficient than binary, but easier to edit later. * GLTF_SEPARATE glTF Separate (.gltf + .bin + textures), Exports multiple files, with separate JSON, binary and texture data. Easiest to edit later.
     :type export_format: typing.Union[str, int]
     :param ui_tab: ui_tab, Export setting categories * GENERAL General, General settings. * MESHES Meshes, Mesh settings. * OBJECTS Objects, Object settings. * ANIMATION Animation, Animation settings.
@@ -243,7 +262,12 @@ def gltf(export_format: typing.Union[str, int] = 'GLB',
     pass
 
 
-def obj(filepath: str = "",
+def obj(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.obj;*.mtl",
         use_selection: bool = False,
@@ -268,6 +292,9 @@ def obj(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Save a Wavefront OBJ File
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -319,7 +346,12 @@ def obj(filepath: str = "",
     pass
 
 
-def x3d(filepath: str = "",
+def x3d(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.x3d",
         use_selection: bool = False,
@@ -336,6 +368,9 @@ def x3d(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Export selection to Extensible 3D file (.x3d)
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
