@@ -1,8 +1,16 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def bvh(filepath: str = "",
+def bvh(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         filter_glob: str = "*.bvh",
         target: typing.Union[str, int] = 'ARMATURE',
         global_scale: float = 1.0,
@@ -16,6 +24,9 @@ def bvh(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Load a BVH motion capture file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
