@@ -2,20 +2,28 @@ import sys
 import typing
 import bpy.types
 
+GenericType = typing.TypeVar("GenericType")
 
-def ply(filepath: str = "",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+
+def ply(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
+        files: bpy.types.
+        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
         directory: str = "",
         filter_glob: str = "*.ply"):
     ''' Load a PLY geometry file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param files: File Path, File path used for importing the PLY file
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
     :param directory: directory
     :type directory: str
     :param filter_glob: filter_glob
@@ -25,12 +33,15 @@ def ply(filepath: str = "",
     pass
 
 
-def stl(filepath: str = "",
+def stl(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         filter_glob: str = "*.stl",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: bpy.types.
+        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
         directory: str = "",
         global_scale: float = 1.0,
         use_scene_unit: bool = False,
@@ -39,12 +50,15 @@ def stl(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Z'):
     ''' Load STL triangle mesh data
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
     :param directory: directory
     :type directory: str
     :param global_scale: Scale
