@@ -1,10 +1,11 @@
 import sys
 import typing
 import bpy.types
-import bpy.context
 
-from . import units
 from . import previews
+from . import units
+
+GenericType = typing.TypeVar("GenericType")
 
 
 def app_template_paths(subdir: str = None):
@@ -20,7 +21,7 @@ def app_template_paths(subdir: str = None):
 
 def blend_paths(absolute: bool = False,
                 packed: bool = False,
-                local: bool = False) -> list:
+                local: bool = False) -> typing.List[str]:
     ''' Returns a list of paths to external files referenced by the loaded .blend file.
 
     :param absolute: When true the paths returned are made absolute.
@@ -29,6 +30,7 @@ def blend_paths(absolute: bool = False,
     :type packed: bool
     :param local: When true skip linked library paths.
     :type local: bool
+    :rtype: typing.List[str]
     :return: path list.
     '''
 
@@ -40,6 +42,7 @@ def escape_identifier(string: str) -> str:
 
     :param string: text
     :type string: str
+    :rtype: str
     :return: The escaped string.
     '''
 
@@ -90,7 +93,8 @@ def load_scripts(reload_scripts: bool = False, refresh_scripts: bool = False):
     pass
 
 
-def make_rna_paths(struct_name: str, prop_name: str, enum_name: str) -> tuple:
+def make_rna_paths(struct_name: str, prop_name: str,
+                   enum_name: str) -> typing.Tuple:
     ''' Create RNA "paths" from given names.
 
     :param struct_name: Name of a RNA struct (like e.g. "Scene").
@@ -99,6 +103,7 @@ def make_rna_paths(struct_name: str, prop_name: str, enum_name: str) -> tuple:
     :type prop_name: str
     :param enum_name: Name of a RNA enum identifier.
     :type enum_name: str
+    :rtype: typing.Tuple
     :return: A triple of three "RNA paths" (most_complete_path, "struct.prop", "struct.prop:'enum'"). If no enum_name is given, the third element will always be void.
     '''
 
@@ -113,13 +118,14 @@ def manual_map():
     pass
 
 
-def modules_from_path(path: str, loaded_modules: set) -> list:
+def modules_from_path(path: str, loaded_modules: typing.Set) -> typing.List:
     ''' Load all modules in a path and return them as a list.
 
     :param path: this path is scanned for scripts and packages.
     :type path: str
     :param loaded_modules: already loaded module names, files matching these names will be ignored.
-    :type loaded_modules: set
+    :type loaded_modules: typing.Set
+    :rtype: typing.List
     :return: all loaded modules.
     '''
 
@@ -134,11 +140,12 @@ def preset_find(name, preset_path, display_name=False, ext='.py'):
     pass
 
 
-def preset_paths(subdir: str) -> list:
+def preset_paths(subdir: str) -> typing.List:
     ''' Returns a list of paths for a specific preset.
 
     :param subdir: preset subdirectory (must not be an absolute path).
     :type subdir: str
+    :rtype: typing.List
     :return: script paths.
     '''
 
@@ -177,14 +184,15 @@ def register_manual_map(manual_hook):
     pass
 
 
-def register_submodule_factory(module_name: str,
-                               submodule_names: list) -> tuple:
+def register_submodule_factory(
+        module_name: str, submodule_names: typing.List[str]) -> typing.Tuple:
     ''' Utility function to create register and unregister functions which simply load submodules, calling their register & unregister functions.
 
     :param module_name: The module name, typically __name__ .
     :type module_name: str
     :param submodule_names: List of submodule names to load and unload.
-    :type submodule_names: list
+    :type submodule_names: typing.List[str]
+    :rtype: typing.Tuple
     :return: register and unregister functions.
     '''
 
@@ -193,7 +201,7 @@ def register_submodule_factory(module_name: str,
 
 def register_tool(tool_cls,
                   *,
-                  after: 'bpy.context.collection' = None,
+                  after=None,
                   separator: bool = False,
                   group: bool = False):
     ''' Register a tool in the toolbar.
@@ -203,7 +211,6 @@ def register_tool(tool_cls,
     :param space_type: Space type identifier.
     :type space_type: str
     :param after: Optional identifiers this tool will be added after.
-    :type after: 'bpy.context.collection'
     :param separator: When true, add a separator before this tool.
     :type separator: bool
     :param group: When true, add a new nested group of tools.
@@ -224,6 +231,7 @@ def resource_path(type: str,
     :type major: int
     :param minor: minor version, defaults to current.
     :type minor: str
+    :rtype: str
     :return: the resource path (not necessarily existing).
     '''
 
@@ -249,7 +257,7 @@ def script_path_user():
 def script_paths(subdir: str = None,
                  user_pref: bool = True,
                  check_all: bool = False,
-                 use_user=True) -> list:
+                 use_user=True) -> typing.List:
     ''' Returns a list of valid script paths.
 
     :param subdir: Optional subdir.
@@ -258,6 +266,7 @@ def script_paths(subdir: str = None,
     :type user_pref: bool
     :param check_all: Include local, user and system paths rather just the paths blender uses.
     :type check_all: bool
+    :rtype: typing.List
     :return: script paths.
     '''
 
@@ -269,18 +278,19 @@ def smpte_from_frame(frame: int, fps=None, fps_base=None) -> str:
 
     :param frame: frame number.
     :type frame: int
+    :rtype: str
     :return: the frame string.
     '''
 
     pass
 
 
-def smpte_from_seconds(time: typing.Union[float, int], fps=None,
-                       fps_base=None) -> str:
+def smpte_from_seconds(time: int, fps=None, fps_base=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: HH:MM:SS:FF . If *fps* and *fps_base* are not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: typing.Union[float, int]
+    :type time: int
+    :rtype: str
     :return: the frame string.
     '''
 
@@ -336,6 +346,7 @@ def user_resource(resource_type, path='', create: bool = False) -> str:
     :type subdir: str
     :param create: Treat the path as a directory and create it if its not existing.
     :type create: bool
+    :rtype: str
     :return: a path.
     '''
 
