@@ -1,12 +1,15 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
 
-def code_from_builtin(shader_name: str) -> dict:
+
+def code_from_builtin(shader_name: str) -> typing.Dict:
     ''' Exposes the internal shader code for query.
 
     :param shader_name: { '2D_UNIFORM_COLOR', '2D_FLAT_COLOR', '2D_SMOOTH_COLOR', '2D_IMAGE', '3D_UNIFORM_COLOR', '3D_FLAT_COLOR', '3D_SMOOTH_COLOR'}
     :type shader_name: str
+    :rtype: typing.Dict
     :return: Vertex, fragment and geometry shader codes.
     '''
 
