@@ -3,6 +3,8 @@ import typing
 import bpy.types
 import mathutils
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class GPUBatch:
     ''' Reusable container for drawable geometry. :arg type: One of these primitive types: { POINTS , LINES , TRIS , LINE_STRIP , LINE_LOOP , TRI_STRIP , TRI_FAN , LINES_ADJ , TRIS_ADJ , LINE_STRIP_ADJ } :type type: str :arg buf: Vertex buffer containing all or some of the attributes required for drawing. :type buf: gpu.types.GPUVertBuf :arg elem: An optional index buffer. :type elem: gpu.types.GPUIndexBuf
@@ -151,23 +153,23 @@ class GPUShader:
         '''
         pass
 
-    def uniform_bool(self, name: str, seq: list):
+    def uniform_bool(self, name: str, seq: typing.List):
         ''' Specify the value of a uniform variable for the current program object.
 
         :param name: Name of the uniform variable whose value is to be changed.
         :type name: str
         :param seq: Value that will be used to update the specified uniform variable.
-        :type seq: list
+        :type seq: typing.List
         '''
         pass
 
-    def uniform_float(self, name: str, value: list):
+    def uniform_float(self, name: str, value: typing.List):
         ''' Specify the value of a uniform variable for the current program object.
 
         :param name: Name of the uniform variable whose value is to be changed.
         :type name: str
         :param value: Value that will be used to update the specified uniform variable.
-        :type value: list
+        :type value: typing.List
         '''
         pass
 
@@ -181,24 +183,24 @@ class GPUShader:
         '''
         pass
 
-    def uniform_int(self, name: str, seq: list):
+    def uniform_int(self, name: str, seq: typing.List):
         ''' Specify the value of a uniform variable for the current program object.
 
         :param name: name of the uniform variable whose value is to be changed.
         :type name: str
         :param seq: Value that will be used to update the specified uniform variable.
-        :type seq: list
+        :type seq: typing.List
         '''
         pass
 
-    def uniform_vector_float(self, location: int, buffer: list, length: int,
-                             count: int):
+    def uniform_vector_float(self, location: int, buffer: typing.List[float],
+                             length: int, count: int):
         ''' Set the buffer to fill the uniform.
 
         :param location: Location of the uniform variable to be modified.
         :type location: int
         :param buffer: The data that should be set. Can support the buffer protocol.
-        :type buffer: list
+        :type buffer: typing.List[float]
         :param length: - 1: float - 2: vec2 or float[2] - 3: vec3 or float[3] - 4: vec4 or float[4] - 9: mat3 - 16: mat4
         :type length: int
         :param count: Specifies the number of elements, vector or matrices that are to be modified.
@@ -217,13 +219,13 @@ class GPUVertBuf:
     ''' Contains a VBO. :param len: Amount of vertices that will fit into this buffer. :type type: int :param format: Vertex format. :type buf: gpu.types.GPUVertFormat
     '''
 
-    def attr_fill(self, id: typing.Union[str, int], data: list):
+    def attr_fill(self, id: typing.Union[int, str], data: typing.List):
         ''' Insert data into the buffer for a single attribute.
 
         :param id: Either the name or the id of the attribute.
-        :type id: typing.Union[str, int]
+        :type id: typing.Union[int, str]
         :param data: Sequence of data that should be stored in the buffer
-        :type data: list
+        :type data: typing.List
         '''
         pass
 
