@@ -2,9 +2,11 @@ import sys
 import typing
 import nodeitems_utils
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class SortedNodeCategory(nodeitems_utils.NodeCategory):
-    def poll(self, context):
+    def poll(self, _context):
         ''' 
 
         '''
@@ -19,15 +21,7 @@ class CompositorNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
         pass
 
 
-class ShaderNewNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-
-class ShaderOldNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
+class ShaderNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
     def poll(self, context):
         ''' 
 
@@ -43,6 +37,38 @@ class TextureNodeCategory(SortedNodeCategory, nodeitems_utils.NodeCategory):
         pass
 
 
+def cycles_aov_node_poll(context):
+    ''' 
+
+    '''
+
+    pass
+
+
+def cycles_shader_nodes_poll(context):
+    ''' 
+
+    '''
+
+    pass
+
+
+def eevee_cycles_shader_nodes_poll(context):
+    ''' 
+
+    '''
+
+    pass
+
+
+def eevee_shader_nodes_poll(context):
+    ''' 
+
+    '''
+
+    pass
+
+
 def group_input_output_item_poll(context):
     ''' 
 
@@ -75,6 +101,30 @@ def node_group_items(context):
     pass
 
 
+def object_cycles_shader_nodes_poll(context):
+    ''' 
+
+    '''
+
+    pass
+
+
+def object_eevee_cycles_shader_nodes_poll(context):
+    ''' 
+
+    '''
+
+    pass
+
+
+def object_eevee_shader_nodes_poll(context):
+    ''' 
+
+    '''
+
+    pass
+
+
 def object_shader_nodes_poll(context):
     ''' 
 
