@@ -1,31 +1,33 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class InfoFunctionRNA:
     args = None
-    ''''''
+    ''' '''
 
     bl_func = None
-    ''''''
+    ''' '''
 
     description = None
-    ''''''
+    ''' '''
 
     global_lookup = None
-    ''''''
+    ''' '''
 
     identifier = None
-    ''''''
+    ''' '''
 
     is_classmethod = None
-    ''''''
+    ''' '''
 
     return_values = None
-    ''''''
+    ''' '''
 
     def build(self):
-        '''
+        ''' 
 
         '''
         pass
@@ -33,37 +35,37 @@ class InfoFunctionRNA:
 
 class InfoOperatorRNA:
     args = None
-    ''''''
+    ''' '''
 
     bl_op = None
-    ''''''
+    ''' '''
 
     description = None
-    ''''''
+    ''' '''
 
     func_name = None
-    ''''''
+    ''' '''
 
     global_lookup = None
-    ''''''
+    ''' '''
 
     identifier = None
-    ''''''
+    ''' '''
 
     module_name = None
-    ''''''
+    ''' '''
 
     name = None
-    ''''''
+    ''' '''
 
     def build(self):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_location(self):
-        '''
+        ''' 
 
         '''
         pass
@@ -71,82 +73,82 @@ class InfoOperatorRNA:
 
 class InfoPropertyRNA:
     array_dimensions = None
-    ''''''
+    ''' '''
 
     array_length = None
-    ''''''
+    ''' '''
 
     bl_prop = None
-    ''''''
+    ''' '''
 
     collection_type = None
-    ''''''
+    ''' '''
 
     default = None
-    ''''''
+    ''' '''
 
     default_str = None
-    ''''''
+    ''' '''
 
     description = None
-    ''''''
+    ''' '''
 
     enum_items = None
-    ''''''
+    ''' '''
 
     fixed_type = None
-    ''''''
+    ''' '''
 
     global_lookup = None
-    ''''''
+    ''' '''
 
     identifier = None
-    ''''''
+    ''' '''
 
     is_argument_optional = None
-    ''''''
+    ''' '''
 
     is_enum_flag = None
-    ''''''
+    ''' '''
 
     is_never_none = None
-    ''''''
+    ''' '''
 
     is_readonly = None
-    ''''''
+    ''' '''
 
     is_required = None
-    ''''''
+    ''' '''
 
     max = None
-    ''''''
+    ''' '''
 
     min = None
-    ''''''
+    ''' '''
 
     name = None
-    ''''''
+    ''' '''
 
     srna = None
-    ''''''
+    ''' '''
 
     type = None
-    ''''''
+    ''' '''
 
     def build(self):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_arg_default(self, force):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_type_description(self, as_ret, as_arg, class_fmt, collection_id):
-        '''
+        ''' 
 
         '''
         pass
@@ -154,86 +156,86 @@ class InfoPropertyRNA:
 
 class InfoStructRNA:
     base = None
-    ''''''
+    ''' '''
 
     bl_rna = None
-    ''''''
+    ''' '''
 
     children = None
-    ''''''
+    ''' '''
 
     description = None
-    ''''''
+    ''' '''
 
     full_path = None
-    ''''''
+    ''' '''
 
     functions = None
-    ''''''
+    ''' '''
 
     global_lookup = None
-    ''''''
+    ''' '''
 
     identifier = None
-    ''''''
+    ''' '''
 
     module_name = None
-    ''''''
+    ''' '''
 
     name = None
-    ''''''
+    ''' '''
 
     nested = None
-    ''''''
+    ''' '''
 
     properties = None
-    ''''''
+    ''' '''
 
     py_class = None
-    ''''''
+    ''' '''
 
     references = None
-    ''''''
+    ''' '''
 
     def build(self):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_bases(self):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_nested_properties(self, ls):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_py_c_functions(self):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_py_functions(self):
-        '''
+        ''' 
 
         '''
         pass
 
     def get_py_properties(self):
-        '''
+        ''' 
 
         '''
         pass
 
 
 def BuildRNAInfo():
-    '''
+    ''' 
 
     '''
 
@@ -241,7 +243,7 @@ def BuildRNAInfo():
 
 
 def GetInfoFunctionRNA(bl_rna, parent_id):
-    '''
+    ''' 
 
     '''
 
@@ -249,7 +251,7 @@ def GetInfoFunctionRNA(bl_rna, parent_id):
 
 
 def GetInfoOperatorRNA(bl_rna):
-    '''
+    ''' 
 
     '''
 
@@ -257,7 +259,7 @@ def GetInfoOperatorRNA(bl_rna):
 
 
 def GetInfoPropertyRNA(bl_rna, parent_id):
-    '''
+    ''' 
 
     '''
 
@@ -265,7 +267,7 @@ def GetInfoPropertyRNA(bl_rna, parent_id):
 
 
 def GetInfoStructRNA(bl_rna):
-    '''
+    ''' 
 
     '''
 
@@ -273,7 +275,7 @@ def GetInfoStructRNA(bl_rna):
 
 
 def float_as_string(f):
-    '''
+    ''' 
 
     '''
 
@@ -281,7 +283,7 @@ def float_as_string(f):
 
 
 def get_direct_functions(rna_type):
-    '''
+    ''' 
 
     '''
 
@@ -289,7 +291,7 @@ def get_direct_functions(rna_type):
 
 
 def get_direct_properties(rna_type):
-    '''
+    ''' 
 
     '''
 
@@ -297,7 +299,7 @@ def get_direct_properties(rna_type):
 
 
 def get_py_class_from_rna(rna_type):
-    '''
+    ''' 
 
     '''
 
@@ -305,7 +307,7 @@ def get_py_class_from_rna(rna_type):
 
 
 def main():
-    '''
+    ''' 
 
     '''
 
@@ -313,7 +315,7 @@ def main():
 
 
 def range_str(val):
-    '''
+    ''' 
 
     '''
 
@@ -321,7 +323,7 @@ def range_str(val):
 
 
 def rna_id_ignore(rna_id):
-    '''
+    ''' 
 
     '''
 
